K means clustering is often used as an unsupervised data-analytics algorithm meant to find the ideal number of possible classes in a given dataset.

This project implements a k-means clustering algorithm pipeline that takes in dataset file(s) such as the one found in the dataset folder and computes the best K for each dataset and outputs into another text file the file name followed by the estimated K for each one.

Allowed only to use numpy package, all other packages are prohibited. Each line in the dataset file represent 1, n dimensional datapoint.